@@ -267,10 +267,10 @@ void MainWindow::playlist_selected(QList<QTreeWidgetItem *> items, int column)
     foreach (item, items)
     {
         openPlaylist = true;
-        if (item == items.takeFirst())
+       /* if (item == items.first())
             openPlaylist = false;
         else
-            openPlaylist = true;
+            openPlaylist = true;*/
         bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
         network->retrieveArticle(item->text(column), existsAlready);
 
@@ -301,6 +301,7 @@ void MainWindow::openArticleInPlayer(QString title, QString article)
      message->setLabelText("Processing " + title);
      player->openArticle(title, article, openPlaylist);
      ui->playerButton->setDown(true);
+     ui->mainWindowButton->setDown(false);
      player->show();
 
      //message->hide();
