@@ -116,12 +116,15 @@ void Player::setPlaylistFocus()
 {
     reload = true;
     this->ui->playListWidget->setCurrentRow(0, QItemSelectionModel::Select);
-    this->openArticleFromLink(ui->playListWidget->currentItem());
+
+    this->openArticleFromLink(ui->playListWidget->item(this->ui->playListWidget->currentRow()));
+    audio->createWav(this->ui->playListWidget->currentItem()->text());
 }
 
 void Player::on_playListWidget_itemClicked(QListWidgetItem *item)
 {
     reload = true;
+    this->ui->playListWidget->setCurrentItem(item);
     this->openArticleFromLink(item);
 }
 
