@@ -17,7 +17,7 @@ class Player : public QWidget
 
 public:
     explicit Player(QWidget *parent = 0);
-    void openArticle(QString itemTitle, QString text, bool playlist);
+    void openArticle(QString itemTitle, QString text, bool playlist = false);
     void clearCurrentArticles();
     void setPlaylistFocus();
     ~Player();
