@@ -14,12 +14,13 @@ Playlist::Playlist(QWidget *parent) :
     ui->treeWidget->setColumnCount(1);
  //   ui->treeWidget->setColumnWidth(0,300);
 
-    box = new QDialogButtonBox(Qt::Horizontal, this);
-    box->addButton("Open", QDialogButtonBox::AcceptRole);
-    box->addButton("Remove", QDialogButtonBox::RejectRole );
-    box->hide();
+ //   box->setLayout();
+ //   box->addButton("Open", QDialogButtonBox::AcceptRole);
+ //   box->addButton("Remove", QDialogButtonBox::RejectRole );
+ /*   box->hide();
     connect(box, SIGNAL(accepted()), this, SLOT(openArticle()));
     connect(box, SIGNAL(rejected()), this, SLOT(deleteArticle()));
+    */
 
 
 
@@ -37,10 +38,13 @@ void Playlist::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
  //   {
         if (item->childCount() == 0)
         {
-            clickedItem = item;
+
+            this->articleSelected(item, column);
+            this->hide();
+          /*  clickedItem = item;
             clickedColumn = column;
             box->show();
-           // this->articleSelected(item, column);
+           // this->articleSelected(item, column);*/
         }
         else
         {
